@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 import os
+import html
 import shutil
-from html.parser import HTMLParser
+
 from tempfile import mkdtemp
 
 from django.template import Context, Template
@@ -55,7 +56,7 @@ class SyntaxColorTagTests(TestCase):
 
         result = Template(content).render(ctx)
 
-        self.assertHTMLEqual(HTMLParser().unescape(result), expected_result)
+        self.assertHTMLEqual(html.unescape(result), expected_result)
 
     def test_should_colorize_table_with_default_lexer(self):
         ctx = Context({'code_string': '<h1>TEST</h1>'})
@@ -78,14 +79,14 @@ class SyntaxColorTagTests(TestCase):
         expected_result = '<h1>TEST</h1>'
         result = Template(content).render(ctx)
 
-        self.assertHTMLEqual(HTMLParser().unescape(result), expected_result)
+        self.assertHTMLEqual(html.unescape(result), expected_result)
 
     def test_should_colorize_noclasses_with_default_lexer(self):
         ctx = Context({'code_string': '<h1>TEST</h1>'})
         content = """{% load syntax_color %}
 {{ code_string|colorize_noclasses }}
 """
-        expected_result = '''<div class="highlight" style="background: #f8f8f8"><pre style="line-height: 125%; margin: 0;"><span></span><span style="color: #008000; font-weight: bold">&lt;h1&gt;</span>TEST<span style="color: #008000; font-weight: bold">&lt;/h1&gt;</span>
+        expected_result = '''<div class="highlight" style="background: #f8f8f8"><pre style="line-height: 125%;"><span></span><span style="color: #008000; font-weight: bold">&lt;h1&gt;</span>TEST<span style="color: #008000; font-weight: bold">&lt;/h1&gt;</span>
 </pre></div>'''
         result = Template(content).render(ctx)
 
@@ -99,4 +100,4 @@ class SyntaxColorTagTests(TestCase):
         expected_result = '<h1>TEST</h1>'
         result = Template(content).render(ctx)
 
-        self.assertHTMLEqual(HTMLParser().unescape(result), expected_result)
+        self.assertHTMLEqual(html.unescape(result), expected_result)
